(function (Drupal, once, drupalSettings) {
  "use strict";

  function toggleDisplay(element) {
    if (element.style.display === "none") {
      element.style.display = "";
    } else {
      element.style.display = "none";
    }
  }

  Drupal.behaviors.heading_highlighter = {
    attach: function (context, settings) {
      settings.headingHighlighter.forEach((highlighter) => {
        // Check for heading container.
        const selector = highlighter["selector"] || "body";
        const containerSearch = once(
          "heading-highlighter-init",
          selector,
          context
        );
        if (!containerSearch.length) {
          console.warn(
            `Heading highlighter could not find container element matching: ${selector}`
          );
          return;
        }
        const container = containerSearch[0];

        // Query for headings inside container.
        const headings = Array.from(
          container.querySelectorAll("h1, h2, h3, h4, h5, h6")
        );
        // Generate heading markers.
        const markers = headings.map((heading) => {
          const tagName = heading.tagName.toLowerCase();
          const marker = document.createElement("span");
          marker.classList = [
            "heading-highlighter__heading",
            "heading-highlighter__heading--" + tagName,
          ].join(" ");
          marker.textContent = tagName.toUpperCase();
          if (!highlighter["highlight_default"]) {
            marker.style.display = "none";
          }
          heading.prepend(marker);
          return marker;
        });

        // Check for toggle button.
        if (highlighter["show_toggle"]) {
          const buttonId = highlighter["id"];
          const buttonSearch = once("toggle-init", `#${buttonId}`, context);
          if (!buttonSearch.length) {
            console.warn("Heading highlighter could not find toggle button");
            return;
          }
          const button = buttonSearch[0];
          // Add toggle action.
          button.addEventListener("click", (e) => {
            button
              .querySelectorAll("span")
              .forEach((span) => toggleDisplay(span));
            markers.forEach((marker) => toggleDisplay(marker));
          });
        }
      });
    },
    detach: function (context, settings) {},
  };
})(Drupal, once, drupalSettings);
